﻿using System;
using System.Collections.ObjectModel;
using System.Windows.Forms;
using ThinkGeo.MapSuite;
using ThinkGeo.MapSuite.Layers;
using ThinkGeo.MapSuite.Styles;
using ThinkGeo.MapSuite.Drawing;
using ThinkGeo.MapSuite.Shapes;
using ThinkGeo.MapSuite.WinForms;
using System.Collections.Generic;

namespace _8849
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            InMemoryFeatureLayer imBlinkAircraft = new InMemoryFeatureLayer();

            BlinkingTextStyle blinkingTextStyle = new BlinkingTextStyle();

            Feature testF = new Feature(0, 0);
            testF.ColumnValues.Add("BlinkONOFF", "ON");
            testF.ColumnValues.Add("AircraftIconType", "Test String");
            testF.ColumnValues.Add("AircraftFontSize", "20");
            testF.ColumnValues.Add("HDirection", "10");

            imBlinkAircraft.InternalFeatures.Add(testF);

            blinkingTextStyle.FillBrushes.Add(GeoBrushes.Red);
            blinkingTextStyle.FillBrushes.Add(new GeoSolidBrush(GeoColor.FromArgb(0, 255, 255, 255)));
            blinkingTextStyle.OverlappingRule = LabelOverlappingRule.AllowOverlapping;
            blinkingTextStyle.DuplicateRule = LabelDuplicateRule.UnlimitedDuplicateLabels;
            imBlinkAircraft.ZoomLevelSet.ZoomLevel01.CustomStyles.Add(blinkingTextStyle);

            //imBlinkAircraft.DrawingMarginPercentage = 50;
            imBlinkAircraft.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            LayerOverlay blinkingOverlay = new LayerOverlay() { AutoRefreshInterval = TimeSpan.FromMilliseconds(200) };
            blinkingOverlay.Layers.Add("BlinkAircraftLayer", imBlinkAircraft);
            winformsMap1.Overlays.Add("BlinkAircraftOverlay", blinkingOverlay);
            //winformsMap1.OverlaysDrawing += wfMap_OverlaysDrawing;
            //winformsMap1.OverlaysDrawn += wfMap_OverlaysDrawn;

            winformsMap1.CurrentExtent = new RectangleShape(-10, 10, 10, -10);
        }



        public class BlinkingTextStyle : TextStyle
        {
            private Collection<GeoBrush> candidates = new Collection<GeoBrush>();

            protected override void DrawCore(IEnumerable<Feature> features, GeoCanvas canvas, Collection<SimpleCandidate> labelsInThisLayer, Collection<SimpleCandidate> labelsInAllLayers)
            {
                foreach (var feature in features)
                {
                    if (feature.ColumnValues["BlinkONOFF"].ToString() == "ON")
                        canvas.DrawText(feature.ColumnValues["AircraftIconType"].ToString(), new GeoFont("Aircraft_b", (float)Convert.ToDouble(feature.ColumnValues["AircraftFontSize"].ToString()), DrawingFontStyles.Regular), GetFillBrush(), new GeoPen(GeoColor.FromArgb(0, 255, 255, 255)), new Collection<ScreenPointF> { ExtentHelper.ToScreenCoordinate(canvas.CurrentWorldExtent, (PointShape)feature.GetShape(), canvas.Width, canvas.Height) }, DrawingLevel, 0, 0, (float)Convert.ToDouble(feature.ColumnValues["HDirection"].ToString()));
                }
            }

            public Collection<GeoBrush> FillBrushes
            {
                get { return candidates; }
            }

            private GeoBrush GetFillBrush()
            {
                Random random = new Random();
                int index = random.Next(candidates.Count);

                return candidates[index];
            }
        }
    }
}
